Class: Chart::Area

Inherits:
Chart show all
Defined in:
lib/writeexcel/charts/area.rb

Overview

SYNOPSIS

To create a simple Excel file with a Area chart using WriteExcel:

 #!/usr/bin/ruby -w

 require 'writeexcel'

 workbook  = WriteExcel.new('chart.xls')
 worksheet = workbook.add_worksheet

 chart     = workbook.add_chart(:type => Chart::Area)

 # Configure the chart.
 chart.add_series(
   :categories => '=Sheet1!$A$2:$A$7',
   :values     => '=Sheet1!$B$2:$B$7',
)

 # Add the worksheet data the chart refers to.
 data = [
     [ 'Category', 2, 3, 4, 5, 6, 7 ],
     [ 'Value',    1, 4, 5, 2, 1, 5 ]
 ]

 worksheet.write('A1', data)

 workbook.close

DESCRIPTION

This module implements Area charts for WriteExcel. The chart object is

created via the Workbook add_chart method:

  chart = workbook.add_chart(:type => Chart::Area)

Once the object is created it can be configured via the following methods that are common to all chart classes:

chart.add_series
chart.set_x_axis
chart.set_y_axis
chart.set_title

These methods are explained in detail in Chart section of WriteExcel. Class specific methods or settings, if any, are explained below.

Area Chart Methods

There aren’t currently any area chart specific methods. See the TODO section of Chart of Writeexcel.

EXAMPLE

Here is a complete example that demonstrates most of the available features when creating a chart.

 #!/usr/bin/ruby -w

 require 'writeexcel'

 workbook  = WriteExcel.new('chart_area.xls')
 worksheet = workbook.add_worksheet
 bold      = workbook.add_format(:bold => 1)

 # Add the worksheet data that the charts will refer to.
 headings = [ 'Number', 'Sample 1', 'Sample 2' ]
 data = [
     [ 2, 3, 4, 5, 6, 7 ],
     [ 1, 4, 5, 2, 1, 5 ],
     [ 3, 6, 7, 5, 4, 3 ]
 ]

 worksheet.write('A1', headings, bold)
 worksheet.write('A2', data)

 # Create a new chart object. In this case an embedded chart.
 chart = workbook.add_chart(:type => Chart::Area, :embedded => 1)

 # Configure the first series. (Sample 1)
 chart.add_series(
   :name       => 'Sample 1',
   :categories => '=Sheet1!$A$2:$A$7',
   :values     => '=Sheet1!$B$2:$B$7',
)

 # Configure the second series. (Sample 2)
 chart.add_series(
   :name       => 'Sample 2',
   :categories => '=Sheet1!$A$2:$A$7',
   :values     => '=Sheet1!$C$2:$C$7',
)

 # Add a chart title and some axis labels.
 chart.set_title (:name => 'Results of sample analysis')
 chart.set_x_axis(:name => 'Test number')
 chart.set_y_axis(:name => 'Sample length (cm)')

 # Insert the chart into the worksheet (with an offset).
 worksheet.insert_chart('D2', chart, 25, 10)

 workbook.close

Constant Summary

Constants inherited from Chart

NonAscii

Constants inherited from Worksheet

Worksheet::Buffer, Worksheet::ColMax, Worksheet::NonAscii, Worksheet::RowMax, Worksheet::StrMax

Constants inherited from BIFFWriter

BIFFWriter::BIFF_Version, BIFFWriter::BigEndian

Instance Attribute Summary

Attributes inherited from BIFFWriter

#byte_order, #data, #datasize

Instance Method Summary collapse

Methods inherited from Chart

#add_series, #close, #data=, #embedded, #embedded=, #encode_utf16, factory, #get_color_indices, #get_color_rbg, #get_line_pattern, #get_line_weight, #parse_series_formula, #prepend, #set_chartarea, #set_default_config_data, #set_default_properties, #set_embedded_config_data, #set_legend, #set_plotarea, #set_title, #set_x_axis, #set_y_axis, #store_3dbarshape, #store_ai, #store_areaformat, #store_axcext, #store_axesused, #store_axis, #store_axis_category_stream, #store_axis_values_stream, #store_axislineformat, #store_axisparent, #store_axisparent_stream, #store_begin, #store_catserrange, #store_chart, #store_chart_stream, #store_chartarea_frame_stream, #store_chartformat, #store_chartformat_stream, #store_chartline, #store_charttext, #store_dataformat, #store_dataformat_stream, #store_defaulttext, #store_dropbar, #store_end, #store_fbi, #store_fontx, #store_frame, #store_legend, #store_legend_stream, #store_legend_text_stream, #store_lineformat, #store_marker_dataformat_stream, #store_markerformat, #store_objectlink, #store_pieformat, #store_plotarea, #store_plotarea_frame_stream, #store_plotgrowth, #store_pos, #store_serauxtrend, #store_series, #store_series_stream, #store_series_text_stream, #store_seriestext, #store_serparent, #store_sertocrt, #store_shtprops, #store_text, #store_tick, #store_title_text_stream, #store_valuerange, #store_window2, #store_x_axis_text_stream, #store_y_axis_text_stream, #using_tmpfile=

Methods inherited from Worksheet

#activate, #active=, #add_write_handler, #autofilter, #center_horizontally, #center_vertically, #close, #comment_params, #convert_date_time, #data_validation, #date_1904=, #encoding, #extract_filter_tokens, #filter_area, #filter_column, #filter_count, #fit_to_pages, #freeze_panes, #hidden, #hidden=, #hide, #hide_gridlines, #hide_zero, #image_mso_size, #image_mso_size=, #images_array, #index, #index=, #insert_chart, #insert_image, #keep_leading_zeros, #merge_cells, #merge_range, #name, #num_images, #num_images=, #object_ids=, #offset, #offset=, #outline_settings, #pack_dv_formula, #pack_dv_string, #parse_filter_expression, #position_object, #prepare_charts, #prepare_comments, #prepare_images, #print_across, #print_area, #print_colmax, #print_colmin, #print_row_col_headers, #print_rowmax, #print_rowmin, #protect, #repeat_columns, #repeat_formula, #repeat_rows, #right_to_left, #select, #selected, #selected=, #set_column, #set_comments_author, #set_first_row_column, #set_first_sheet, #set_footer, #set_h_pagebreaks, #set_header, #set_landscape, #set_margin_bottom, #set_margin_left, #set_margin_right, #set_margin_top, #set_margins, #set_margins_LR, #set_margins_TB, #set_page_view, #set_paper, #set_portrait, #set_print_scale, #set_row, #set_selection, #set_start_page, #set_tab_color, #set_v_pagebreaks, #set_zoom, #sheet_type, #show_comments, #split_panes, #store_autofilter, #store_colinfo, #store_dimensions, #store_dval, #store_filtermode, #store_formula, #store_mso_client_anchor, #store_mso_client_data, #store_mso_client_text_box, #store_mso_dg, #store_mso_dg_container, #store_mso_drawing_text_box, #store_mso_opt_chart, #store_mso_opt_comment, #store_mso_opt_filter, #store_mso_opt_image, #store_mso_sp, #store_mso_sp_container, #store_mso_spgr, #store_mso_spgr_container, #store_note, #store_obj_chart, #store_obj_comment, #store_obj_filter, #store_obj_image, #store_selection, #store_txo, #store_txo_continue_1, #store_txo_continue_2, #title_colmax, #title_colmin, #title_rowmax, #title_rowmin, #write, #write_blank, #write_col, #write_comment, #write_date_time, #write_formula, #write_number, #write_row, #write_string, #write_url, #write_url_range, #write_utf16be_string, #write_utf16le_string

Methods inherited from BIFFWriter

#add_continue, #add_mso_generic, #append, #clear_data_for_test, #get_data, #not_using_tmpfile, #prepend, #set_byte_order, #store_bof, #store_eof

Constructor Details

#initialize(*args) ⇒ Area

new()



129
130
131
# File 'lib/writeexcel/charts/area.rb', line 129

def initialize(*args)   # :nodoc:
  super
end

Instance Method Details

#store_chart_typeObject

_store_chart_type()

Implementation of the abstract method from the specific chart class.

Write the AREA chart BIFF record. Defines a area chart type.



141
142
143
144
145
146
147
148
149
150
# File 'lib/writeexcel/charts/area.rb', line 141

def store_chart_type   # :nodoc:
  record = 0x101A     # Record identifier.
  length = 0x0002     # Number of bytes to follow.
  grbit  = 0x0001     # Option flags.

  header = [record, length].pack('vv')
  data = [grbit].pack('v')

  append(header, data)
end